@@ -14,9 +14,9 @@ DaskClusterTypes = {
         "slurm": ("SLURM", "dask_jobqueue", "SLURMCluster"),
         "oar": ("OAR", "dask_jobqueue", "OARCluster"),
         "kube": ("Kubernetes", "dask_kubernetes", "KubeCluster"),
-        "azureml": ("Azure ML", "dask_cloudprovider", "AzureMLCluster"),
-        "ecs": ("AWS ECS", "dask_cloudprovider", "ECSCluster"),
-        "fargate": ("AWS ECS on Fargate", "dask_cloudprovider", "FargateCluster"),
+        "azurevm": ("Azure VM", "dask_cloudprovider.azure", "AzureVMCluster"),
+        "ecs": ("AWS ECS", "dask_cloudprovider.aws", "ECSCluster"),
+        "fargate": ("AWS ECS on Fargate", "dask_cloudprovider.aws", "FargateCluster"),
     }.items()
 }
 
@@ -73,7 +73,9 @@ class DaskResource:
                 Permissive(
                     {
                         "address": Field(
-                            String, description="Address of a Scheduler server.", is_required=False,
+                            String,
+                            description="Address of a Scheduler server.",
+                            is_required=False,
                         ),
                         "timeout": Field(
                             Int,
@@ -91,7 +93,9 @@ class DaskResource:
                             is_required=False,
                         ),
                         "security": Field(
-                            Bool, description="Optional security information.", is_required=False,
+                            Bool,
+                            description="Optional security information.",
+                            is_required=False,
                         ),
                         "asynchronous": Field(
                             Bool,
